@@ -56,10 +56,6 @@ class TestDemoDryRuns:
         result = shell(f"cd {DEMO_DIR}/cmd.exe && {CMD_SEQ}")
         assert result.exit_code == 0
 
-    def test_nextflow(self):
-        result = shell(f"cd {DEMO_DIR}/nextflow && {CMD_SEQ}")
-        assert result.exit_code == 0
-
     def test_blender(self):
         result = shell(f"cd {DEMO_DIR}/blender && {CMD_SEQ}")
         assert result.exit_code == 0
@@ -165,15 +161,6 @@ class TestDemoDryRuns:
         )
         assert result.exit_code == 0
 
-    def test_nextflow_out(self):
-        demo_name = "nextflow"
-        result = shell(
-            f"cd {DEMO_DIR} && yd-provision -D -c {demo_name}/config.toml && yd-submit"
-            f" -D -c {demo_name}/config.toml && yd-instantiate -D -c"
-            f" {demo_name}/config.toml"
-        )
-        assert result.exit_code == 0
-
     def test_blender_out(self):
         demo_name = "blender"
         result = shell(
