@@ -125,11 +125,17 @@ def main():
         submit_json_raw(ARGS_PARSER.json_raw)
         return
 
+    # Direct file > file supplied using '-r' > file supplied in config file
     wr_data_file = (
-        CONFIG_WR.wr_data_file
-        if ARGS_PARSER.work_req_file is None
-        else ARGS_PARSER.work_req_file
+        (
+            CONFIG_WR.wr_data_file
+            if ARGS_PARSER.work_req_file is None
+            else ARGS_PARSER.work_req_file
+        )
+        if ARGS_PARSER.work_requirement_file_positional is None
+        else ARGS_PARSER.work_requirement_file_positional
     )
+
     csv_files = (
         CONFIG_WR.csv_files if ARGS_PARSER.csv_files is None else ARGS_PARSER.csv_files
     )
@@ -155,6 +161,12 @@ def main():
         )
 
     elif wr_data_file is not None:
+
+        if ARGS_PARSER.jsonnet_dry_run and not wr_data_file.lower().endswith("jsonnet"):
+            raise Exception(
+                f"Option '--jsonnet-dry-run' can only be used with files ending in '.jsonnet'"
+            )
+
         wr_data_file = relpath(wr_data_file)
         print_log(f"Loading Work Requirement data from: '{wr_data_file}'")
 
@@ -1188,10 +1200,6 @@ def create_task(
     # and added to the list of required files.
     if task_type in ["bash", "powershell", "python", "cmd", "bat"]:
         if executable is None:
-            if task_number == 1:  # Only report this the first time
-                print_log(
-                    f"Note: no 'executable' specified for '{task_type}' Task Type"
-                )
             return _make_task(flatten_input_paths)
 
         UPLOADED_FILES.add_input_file(
@@ -1273,7 +1281,7 @@ def create_task(
         args = docker_env_list + docker_options + [executable] + args
 
         # Set up the environment used by the script to run Docker
-        # Add the username and password, if present
+        # Add the username and password, if present, and the registry
         docker_username = task_data.get(
             DOCKER_USERNAME,
             task_group_data.get(
@@ -1296,6 +1304,20 @@ def create_task(
             if docker_username is not None and docker_password is not None
             else {}
         )
+        docker_registry = task_data.get(
+            DOCKER_REGISTRY,
+            task_group_data.get(
+                DOCKER_REGISTRY,
+                wr_data.get(DOCKER_REGISTRY, config_wr.docker_registry),
+            ),
+        )
+        env_copy.update(
+            {
+                "DOCKER_REGISTRY": docker_registry,
+            }
+            if docker_registry is not None
+            else {}
+        )
         return _make_task(flatten_input_paths)
 
     else:
